@@ -5,7 +5,7 @@ mul <- function(s, c)
   if(l < n)
     c <- c(c, rep(c[l], (n - l)))
   for(i in 1:n)
-    s[[i]]$x <- s[[i]]$x * c[i]
+    s[[i]]$amp <- s[[i]]$amp * c[i]
   return(s)
 }
 
@@ -16,7 +16,7 @@ add <- function(s, c)
   if(l < n)
     c <- c(c, rep(c[l], (n - l)))
   for(i in 1:n)
-    s[[i]]$x <- s[[i]]$x + c[i]
+    s[[i]]$amp <- s[[i]]$amp + c[i]
   return(s)
 }
 
@@ -27,6 +27,6 @@ pow <- function(s, c)
   if(l < n)
     c <- c(c, rep(c[l], (n - l)))
   for(i in 1:n)
-    s[[i]]$x <- s[[i]]$x ^ c[i]
+    s[[i]]$amp <- s[[i]]$amp ^ c[i]
   return(s)
 }
